{% extends 'spectator_core/base.html' %}

{% block reading_nav_active %}active{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="breadcrumb-item"><a href="{% url 'spectator:reading:home' %}">Reading</a></li>
{% endblock %}


{% block sidebar %}

    {% load spectator_core %}
    {% current_url_name as url_name %}

    {% if url_name != 'spectator:reading:home' %}
		{% load spectator_reading %}
        {% in_progress_publications_card %}
    {% endif %}

    {% reading_years_card current_year=year %}

{% endblock sidebar %}
